==> org.eclipse.incquery.uml.source_1.0.0.201506301446.jar: org/eclipse/incquery/uml/derivedfeatures/PackageOwnedTypeMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.PackageOwnedTypeQuerySpecification;
import org.eclipse.uml2.uml.Type;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.packageOwnedType pattern,
 * to be used in conjunction with {@link PackageOwnedTypeMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see PackageOwnedTypeMatcher
 * @see PackageOwnedTypeProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class PackageOwnedTypeMatch extends BasePatternMatch {
  private org.eclipse.uml2.uml.Package fSelf;
  
  private Type fTemp2;
  
  private static List<String> parameterNames = makeImmutableList("self", "temp2");
  
  private PackageOwnedTypeMatch(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
    this.fSelf = pSelf;
    this.fTemp2 = pTemp2;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("temp2".equals(parameterName)) return this.fTemp2;
    return null;
  }
  
  public org.eclipse.uml2.uml.Package getSelf() {
    return this.fSelf;
  }
  
  public Type getTemp2() {
    return this.fTemp2;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (org.eclipse.uml2.uml.Package) newValue;
    	return true;
    }
    if ("temp2".equals(parameterName) ) {
    	this.fTemp2 = (org.eclipse.uml2.uml.Type) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final org.eclipse.uml2.uml.Package pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setTemp2(final Type pTemp2) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fTemp2 = pTemp2;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.packageOwnedType";
  }
  
  @Override
  public List<String> parameterNames() {
    return PackageOwnedTypeMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fTemp2};
  }
  
  @Override
  public PackageOwnedTypeMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fTemp2) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"temp2\"=" + prettyPrintValue(fTemp2)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fTemp2 == null) ? 0 : fTemp2.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof PackageOwnedTypeMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    PackageOwnedTypeMatch other = (PackageOwnedTypeMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fTemp2 == null) {if (other.fTemp2 != null) return false;}
    else if (!fTemp2.equals(other.fTemp2)) return false;
    return true;
  }
  
  @Override
  public PackageOwnedTypeQuerySpecification specification() {
    try {
    	return PackageOwnedTypeQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static PackageOwnedTypeMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pTemp2 the fixed value of pattern parameter temp2, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static PackageOwnedTypeMatch newMutableMatch(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
    return new Mutable(pSelf, pTemp2);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pTemp2 the fixed value of pattern parameter temp2, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static PackageOwnedTypeMatch newMatch(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
    return new Immutable(pSelf, pTemp2);
  }
  
  private static final class Mutable extends PackageOwnedTypeMatch {
    Mutable(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
      super(pSelf, pTemp2);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends PackageOwnedTypeMatch {
    Immutable(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
      super(pSelf, pTemp2);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.2.0.201602080945.jar: org/eclipse/incquery/uml/derivedfeatures/PackageOwnedTypeMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.PackageOwnedTypeQuerySpecification;
import org.eclipse.uml2.uml.Type;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.packageOwnedType pattern,
 * to be used in conjunction with {@link PackageOwnedTypeMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see PackageOwnedTypeMatcher
 * @see PackageOwnedTypeProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class PackageOwnedTypeMatch extends BasePatternMatch {
  private org.eclipse.uml2.uml.Package fSelf;
  
  private Type fTemp2;
  
  private static List<String> parameterNames = makeImmutableList("self", "temp2");
  
  private PackageOwnedTypeMatch(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
    this.fSelf = pSelf;
    this.fTemp2 = pTemp2;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("temp2".equals(parameterName)) return this.fTemp2;
    return null;
  }
  
  public org.eclipse.uml2.uml.Package getSelf() {
    return this.fSelf;
  }
  
  public Type getTemp2() {
    return this.fTemp2;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (org.eclipse.uml2.uml.Package) newValue;
    	return true;
    }
    if ("temp2".equals(parameterName) ) {
    	this.fTemp2 = (Type) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final org.eclipse.uml2.uml.Package pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setTemp2(final Type pTemp2) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fTemp2 = pTemp2;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.packageOwnedType";
  }
  
  @Override
  public List<String> parameterNames() {
    return PackageOwnedTypeMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fTemp2};
  }
  
  @Override
  public PackageOwnedTypeMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fTemp2) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"temp2\"=" + prettyPrintValue(fTemp2)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fTemp2 == null) ? 0 : fTemp2.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof PackageOwnedTypeMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    PackageOwnedTypeMatch other = (PackageOwnedTypeMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fTemp2 == null) {if (other.fTemp2 != null) return false;}
    else if (!fTemp2.equals(other.fTemp2)) return false;
    return true;
  }
  
  @Override
  public PackageOwnedTypeQuerySpecification specification() {
    try {
    	return PackageOwnedTypeQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static PackageOwnedTypeMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pTemp2 the fixed value of pattern parameter temp2, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static PackageOwnedTypeMatch newMutableMatch(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
    return new Mutable(pSelf, pTemp2);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pTemp2 the fixed value of pattern parameter temp2, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static PackageOwnedTypeMatch newMatch(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
    return new Immutable(pSelf, pTemp2);
  }
  
  private static final class Mutable extends PackageOwnedTypeMatch {
    Mutable(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
      super(pSelf, pTemp2);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends PackageOwnedTypeMatch {
    Immutable(final org.eclipse.uml2.uml.Package pSelf, final Type pTemp2) {
      super(pSelf, pTemp2);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}
